 %% Load image, process image and determine dowel rod lengths
close all
clear all
clc

filename = 'ball.jpg'; %%% filename - file location of image
scaleDown = 0.0205;%%% scaleDown - percentage of downsample
BmaxH=60; % Max height of sculpture (cm)
Lb=121.92; % Length of the dowel rods you ordered (121.92 cm -> 4 feet)
LbC=2; % Length subtracted from dowel rod length to account for cutting (cm)
unitTitle = 'cm'; % units used

[out, B, Blength, BlengthR, A] = image2dowel(filename,scaleDown, BmaxH, Lb, LbC, unitTitle);

numDowels=length(out);
[nPx, nPy] = size(Blength);

%% Create xyKey for finding pixels you are putting dowel rods in:
for yyy=1:nPy
    clear temp     
    temp(:,1)=1:nPx;
    temp(:,2)=ones(1,nPx)*yyy;
    if yyy==1
        xyKey=temp;
      else
        xyKey=[xyKey; temp];
    end
    
end
  
%% Find number of cuts for each dowel rod

for j=1:numDowels
    lennie(j)=length(out{j});
end
[s1, s2]=sort(lennie);

%% Create output structure for cutting multiple dowel rods at once

numAt1=5; % number of dowel rods to cut at once 
bundle=1; % bundle that you are currently cutting   

spacing = 1:numAt1:numDowels; % spacing for bundles that are cut
indSS=spacing(bundle);
dowelTotalA=1:numDowels;
dowelNumA=dowelTotalA(indSS:indSS+numAt1-1); % indices of dowel rods to be cut

clear Z
for j=1:numAt1 % 1:numDowels
    clear output
    dowelNum=dowelNumA(j);
    dowelP=out{dowelNum};

    output(:,1)=BlengthR(dowelP);
    output(:,2)=(dowelP);
    
    output(:,3)=xyKey(dowelP,1);
    output(:,4)=xyKey(dowelP,2);
    Z(j).output=output;
    Z(j).numCuts=size(output,1);
    Z(j).dowelNum=dowelNum;

end

%% Display output
subbie=ceil(sqrt(numAt1));
maxCuts=max(cat(1,Z.numCuts));

figure('Color',[1 1 1],'Position',[550 0 850 1000])

for pp=1:maxCuts
    clc
    for dowel=1:numAt1
        clear output
        output=Z(dowel).output;
        numCuts=Z(dowel).numCuts;
        dowelNum=Z(dowel).dowelNum;
        
        if pp>numCuts
            
            disp(['---------- DOWEL #',num2str(dowel),' (',num2str(dowelNum), ')----------'])
            disp('COMPLETED');
            disp([' '])
            
            
        else
            disp(['---------- DOWEL #',num2str(dowel),' (',num2str(dowelNum), ')----------'])
            disp(['CUT LENGTH: ',num2str(output(pp,1)), ' CM'])
            disp(['THIS IS CUT NUMBER ',num2str(pp),' OUT OF ',num2str(numCuts)])
            disp(['THERE SHOULD BE AT LEAST ' num2str(round(sum(output(pp:numCuts,1)))),' CM LEFT'])
            disp(['LOCATION: X = ',num2str(output(pp,4)),' ;Y = ',num2str(output(pp,3))])
            disp([' '])
            
            %%% PLOT OUTPUT
            subplot(subbie,subbie-1,dowel)
            imagesc(Blength);
            axis image off
            colormap('gray'); hold on
            plot(output(:,4),output(:,3),'og')
            plot(output(pp,4),output(pp,3),'or','LineWidth',2)
            title(['DOWEL #',num2str(dowel),' (',num2str(dowelNum), ')'])
        end
    end
    pause;
    clc    
end

%% Plot Status
figure('Color',[1 1 1],'Position',[0 0 850 1000])

lastCut=dowelNumA(numAt1);
cutsMade=horzcat(out{1:lastCut});
percentComplete=length(cutsMade)/length(BlengthR);

imagesc(Blength);
axis image off
colormap('gray'); hold on

title(['Percent Cut:    ',num2str(percentComplete*100),' %'],'FontSize',18)

plot(xyKey(cutsMade,2),xyKey(cutsMade,1),'or','LineWidth',2);
